/*--------------------------------------------------------------------------*/
/*                                                                          */
/*                OS/2 2.0 REX Driver for  IBM TCP/IP version 2.0           */
/*                                                                          */
/*                                CIS.CMD                                   */
/*                                                                          */
/*            ..................................................            */
/*                                                                          */
/* Sample attachment script for dialing into CIS                            */
/*                                                                          */
/* The script sends the dial string to the modem and then logs into the     */
/* terminal server using the userid/password.                               */
/*                                                                          */
/*                                                                          */
/*                                                                          */
/* Author: Klaus-Dieter Trog    100013,1542@compuserve.com (Freeware)       */
/*--------------------------------------------------------------------------*/

parse arg interface, ppp_com, ppp_cmd, dialcmd, userid, password

/*--------------------------------------------------------------------------*/
/*                   Initialization and Main Script Code                    */
/*--------------------------------------------------------------------------*/

If RxFuncQuery('SysLoadFuncs') <> 0 Then
   rcy = RxFuncAdd('SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs')
Call Sysloadfuncs
debug = 0

/* Set some definitions for easier COM strings */
cr='0d'x
crlf='0d0a'x
cis_hostname = 'f374a04ee1ed653a'x
cis_userid =   '55f36572a0c9443a'x
cis_password = 'e1f3f3776f72e43a'x

/* Set fixed Values */
mdm_str1 = 'AT&F'
mdm_str2 = 'ATZ1'
dialcmd = 'ATDT069-20976'
userid = '100013,1542'
password = '*'

say ''
say 'COMPUSERVE - PPP Server Connection Script by kdt',
    '(interface' interface')'

/* Prompt for missing information */
if dialcmd = '' then do
   call charout , 'Dial Command: '
   parse pull dialcmd
end
if userid = '' | userid = '*' then do
   call charout , 'User Name: '
   parse pull userid
end
else do
   say 'User:' userid
end
if password = '' | password = '*' then do
   call charout , 'Password: '
   password = readpass()
end

/* Flush any stuff left over from previous COM activity */
call flush_receive

/* Init modem strings */
call charout , 'Initializing Modem...' || crlf
call send mdm_str1 || cr
call waitfor 'OK' ; call flush_receive 'echo'
call send mdm_str2 || cr
call waitfor 'OK' ; call flush_receive 'echo'

/* Dial the remote server */
call charout , 'Now Dialing...' || crlf

/* Wait for connection */
call send dialcmd || cr
call waitfor 'CONNECT' ; call waitfor crlf

/* Handle login.  We wait for standard strings, and then flush anything */
/* else to take care of trailing spaces, etc..                          */
call send  cr
call waitfor cis_hostname ; call flush_receive 'echo'
call send 'CIS' || cr
call waitfor cis_userid ; call flush_receive 'echo'
call send userid || '/GO:PPPCONNECT' || cr
call waitfor cis_password ; call flush_receive 'echo'
call send password || cr

/* Wait for the main prompt and then send the "ppp" command */
call waitfor 'PPP' ; call flush_receive 'echo'
call send 'PPP' || cr

/* Parse the results of the PPP  command to determine our address. */
/* We use the "waitfor_buffer" variable from the waitfor routine   */
/* to parse the stuff we get from the line  after waiting for an   */
/* appropriate point in the data stream.                           */
/* Flush anything else */
call flush_receive 'echo'


say 'PPP Connection Established'

/* All done */
exit 0


/*--------------------------------------------------------------------------*/
/*                            send ( sendstring)                            */
/*..........................................................................*/
/*                                                                          */
/* Routine to send a character string off to the modem.                     */
/*                                                                          */
/*--------------------------------------------------------------------------*/

send:

   parse arg sendstring
   call ppp_com_output interface , sendstring

   return


/*--------------------------------------------------------------------------*/
/*                    waitfor ( waitstring , [timeout] )                    */
/*..........................................................................*/
/*                                                                          */
/* Waits for the supplied string to show up in the COM input.  All input    */
/* from the time this function is called until the string shows up in the   */
/* input is accumulated in the "waitfor_buffer" variable.                   */
/*                                                                          */
/* If timeout is specified, it says how long to wait if data stops showing  */
/* up on the COM port (in seconds).                                                         */
/*                                                                          */
/*--------------------------------------------------------------------------*/

waitfor:

   parse arg waitstring , timeout
   if timeout = '' then
     timeout = 5000    /* L O N G   delay if not specified */
   waitfor_buffer = '' ; done = -1; curpos = 1
   ORI_TIME=TIME('E')

   if (remain_buffer = 'REMAIN_BUFFER') then do
      remain_buffer = ''
   end

   do while (done = -1)
      if (remain_buffer \= '') then do
         line = remain_buffer
         remain_buffer = ''
       end
       else do
         line = ppp_com_input(interface,,10)
      end
      waitfor_buffer = waitfor_buffer || line
      index = pos(waitstring,waitfor_buffer)
      if (index > 0) then do
         remain_buffer = substr(waitfor_buffer,index+length(waitstring))
         waitfor_buffer = delstr(waitfor_buffer,index+length(waitstring))
         done = 0
      end
      call charout , substr(waitfor_buffer,curpos)
      x_val = '[' || C2X(substr(waitfor_buffer,curpos)) || ']'
      if X_val <> '[]' & debug then call charout , crlf || x_val
      curpos = length(waitfor_buffer)+1
      if ((done \= 0) & (TIME('E')>timeout)) then do
        call lineout , ' WAITFOR: timed out '
        done = 1
       end
   end
   timeout=0
   RC=done
 return RC



/*--------------------------------------------------------------------------*/
/*                               readpass ()                                */
/*..........................................................................*/
/*                                                                          */
/* Routine used to read a password from the user without echoing the        */
/* password to the screen.                                                  */
/*                                                                          */
/*--------------------------------------------------------------------------*/

readpass:

  answer = ''
  do until key = cr
    key = SysGetKey('NOECHO')
    if key \= cr then do
      answer = answer || key
    end
  end
  say ''
  return answer


/*--------------------------------------------------------------------------*/
/*                             flush_receive ()                             */
/*..........................................................................*/
/*                                                                          */
/* Routine to flush any pending characters to be read from the COM port.    */
/* Reads everything it can until nothing new shows up for 100ms, at which   */
/* point it returns.                                                        */
/*                                                                          */
/* The optional echo argument, if 1, says to echo flushed information.      */
/*                                                                          */
/*--------------------------------------------------------------------------*/

flush_receive:

   parse arg echo

   /* If echoing the flush - take care of waitfor remaining buffer */
   if (echo \= '') & (length(remain_buffer) > 0) then do
      call charout , remain_buffer
      remain_buffer = ''
   end

   /* Eat anything left in the modem or COM buffers */
   /* Stop when nothing new appears for 100ms.      */

   do until line = ''
     line = ppp_com_input(interface,,100)
     if echo \= '' then
        call charout , line
   end

   return
